Index: chrome/browser/chromeos/login/login_utils.h |
=================================================================== |
--- chrome/browser/chromeos/login/login_utils.h (revision 42598) |
+++ chrome/browser/chromeos/login/login_utils.h (working copy) |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_UTILS_H_ |
-#define CHROME_BROWSER_CHROMEOS_LOGIN_UTILS_H_ |
+#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_LOGIN_UTILS_H_ |
+#define CHROME_BROWSER_CHROMEOS_LOGIN_LOGIN_UTILS_H_ |
#include <string> |
#include <vector> |
@@ -17,19 +17,27 @@ |
namespace chromeos { |
-namespace login_utils { |
+class LoginUtils { |
+ public: |
+ // Get LoginUtils singleton object. If it was not set before, new default |
+ // instance will be created. |
+ static LoginUtils* Get(); |
-// Invoked after the user has successfully logged in. This launches a browser |
-// and does other bookkeeping after logging in. |
-void CompleteLogin(const std::string& username, |
- std::vector<std::string> cookies); |
+ // Set LoginUtils singleton object for test purpose only! |
+ static void Set(LoginUtils* ptr); |
-// Creates and returns the authenticator to use. The caller owns the returned |
-// Authenticator and must delete it when done. |
-Authenticator* CreateAuthenticator(LoginStatusConsumer* consumer); |
+ virtual ~LoginUtils() {} |
-} // namespace login_utils |
+ // Invoked after the user has successfully logged in. This launches a browser |
+ // and does other bookkeeping after logging in. |
+ virtual void CompleteLogin(const std::string& username, |
+ std::vector<std::string> cookies) = 0; |
+ // Creates and returns the authenticator to use. The caller owns the returned |
+ // Authenticator and must delete it when done. |
+ virtual Authenticator* CreateAuthenticator(LoginStatusConsumer* consumer) = 0; |
+}; |
+ |
} // namespace chromeos |
-#endif // CHROME_BROWSER_CHROMEOS_LOGIN_UTILS_H_ |
+#endif // CHROME_BROWSER_CHROMEOS_LOGIN_LOGIN_UTILS_H_ |
Property changes on: chrome/browser/chromeos/login/login_utils.h |
___________________________________________________________________ |
Added: svn:mergeinfo |